@@ -51,6 +51,7 @@
 // We mean it.
 //
 
+#include <QtWidgets/private/qtwidgetsglobal_p.h>
 #include "qwindowsstyle_p.h"
 #include "qcommonstyle_p.h"
 
@@ -72,6 +73,7 @@ public:
     static int fixedPixelMetric(QStyle::PixelMetric pm);
     static qreal devicePixelRatio(const QWidget *widget = 0)
         { return widget ? widget->devicePixelRatioF() : QWindowsStylePrivate::appDevicePixelRatio(); }
+    static qreal nativeMetricScaleFactor(const QWidget *widget = Q_NULLPTR);
 
     bool hasSeenAlt(const QWidget *widget) const;
     bool altDown() const { return alt_down; }
@@ -104,3 +106,4 @@ QT_END_NAMESPACE
 #endif // QT_NO_STYLE_WINDOWS
 
 #endif //QWINDOWSSTYLE_P_P_H
+;
